@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsdelf3.4"
-#define HOST_OS_NAME "freebsdelf3"
-#define HOST_OS_VERSION "3.4"
+#define HOST_OS "freebsdelf4.0"
+#define HOST_OS_NAME "freebsdelf4"
+#define HOST_OS_VERSION "4.0"
 #define HOST_ARCH "i386"
-#define HOST_NAME "newt.mcl.cs.columbia.edu"
+#define HOST_NAME "elk.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Mon Apr  3 19:36:19 EDT 2000"
+#define CONFIG_DATE "Tue Jan  1 19:38:10 EST 1980"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s4"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s4"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "3.4"
+#define HOST_HEADER_VERSION "4.0"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -48,6 +48,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
 #define HAVE_SETITIMER 1
+#define HAVE_SETRESUID 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -283,6 +284,7 @@
 #define MOUNT_TYPE_CDFS "cd9660"
 #define MOUNT_TYPE_PCFS "msdos"
 #define MOUNT_TYPE_MFS "mfs"
+#define MOUNT_TYPE_IGNORE MNT_IGNORE
 #define MOUNT_TYPE_UNIONFS MNT_UNION
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs3"
@@ -292,6 +294,7 @@
 #define MNTTAB_TYPE_MFS "mfs"
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_IGNORE 0x800000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
@@ -321,4 +324,5 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
